Glossary
--------
.. glossary::
    API
        Application Program Interface - A contract between applications that defines
        the patterns of interaction between two application components.

    ElementTree
        A Python library used to parse XML data.

    JSON
        JavaScript Object Notation. A format that allows for the markup of structured
        data based on the syntax of JavaScript Objects.

    SOA
        Service-Oriented Architecture. When an application is made of components
        connected across a network.

    XML
        eXtensible Markup Language. A format that allows for the markup of structured
        data.

.. dragndrop:: web_glossary1
    :feedback: Try again!
    :match_1: API||| A contract between applications that defines the patterns of interaction between two application components.
    :match_2: ElementTree||| A built-in Python library used to parse XML data.
    :match_3: JSON|||A format that allows for the markup of structured data based on the syntax of JavaScript Objects.
    :match_4: SOA|||When an application is made of components connected across a network.
    :match_5: XML|||A format that allows for the markup of structured data and is extensible.

    Match each term to its definition.
